==> nextcloud-21.0.4.tgz: nextcloud/apps/updatenotification/l10n/sc.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} est a disponimentu. Otene è àteras informatziones subra comente pònnere in esecutzione s'agiornamentu.",
    "Channel updated" : "Canale agiornadu",
    "Web updater is disabled" : "S'agiornamentu web est disativadu",
    "Update notifications" : "Notìficas de is agiornamentos",
    "The update server could not be reached since %d days to check for new updates." : "Su serbidore no si podet sighire dae %d dies pro controllare si b'at agiornamentos noos.",
    "Please check the Nextcloud and server log files for errors." : "Controla is archìvios de registru de Nextcloud e de su serbidore a sa chirca de is errores.",
    "Update to %1$s is available." : "Agiornamentu a %1$s a disponimentu.",
    "Update for %1$s to version %2$s is available." : "Est a disponimentu s'agiornamentu de %1$s a sa versione %2$s.",
    "Update for {app} to version %s is available." : "Est a disponimentu s'agiornamentu de {app} a sa versione %s.",
    "Update notification" : "Notìficas de agiornamentu",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Visualiza is notìficas de is agiornamentos pro Nextcloud e fruni su SSO pro sa funtzione de agiornamentu.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Sa versione chi ses ponende in esecutzione non s'est mantenende prus. Segura·ti de agiornare a una versione suportada cantu in antis.",
    "Apps missing compatible version" : "Aplicatziones sena versione cumpatìbile",
    "View in store" : "Visualiza in sa butega",
    "Apps with compatible version" : "Aplicatzione cun versione cumpatìbile",
    "Open updater" : "Aberi sa funtzione de agiornamentu",
    "Download now" : "Iscàrriga immoe",
    "Please use the command line updater to update." : "Imprea sa funtzione de agiornamentu dae sa lìnia de cumandu pro agiornare.",
    "What's new?" : "Ite noas?",
    "The update check is not yet finished. Please refresh the page." : "Su controllu de is agiornamentos no est terminadu ancora. Agiorna sa pàgina.",
    "Your version is up to date." : "Sa versione tua est agiornada.",
    "A non-default update server is in use to be checked for updates:" : "Ses impreende unu serbidore non predefinidu pro controllare is agiornamentos:",
    "Update channel:" : "Canale de agiornamentu:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Podes agiornare semper a una versine noa. Ma non podes torrare mai a una versione de in antis.",
    "Notify members of the following groups about available updates:" : "Notìficas a is membros de is grupos in fatu in contu de sa disponibilidade de agiornamentos:",
    "Only notifications for app updates are available." : "Sunt a disponimentu isceti is notìficas pro is agiornamentos de is aplicatziones.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Su canale de agiornamentu seletzionadu faghet chi is notìficas dedicadas a su serbidores siant in disusu.",
    "The selected update channel does not support updates of the server." : "Su canale de agiornamentu seletzionadu non suportat is agiornamentos de su serbidore.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Una versione noa est a disponimentu: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Càstia chi, a pustis de una versione noa, s'agiornamentu si visualizat isceti a pustis de sa prima versione minore o a pustis. Publicamus in su tempus versiones noas a is utentes nostros e, a bortas, brincamus una versione, si essint a campu problemas. Àteras informatziones in contu de agiornamentos e de is canales de publicatzione {link} ",
    "Checked on {lastCheckedDate}" : "Controlladu su {lastCheckedDate}",
    "Checking apps for compatible versions" : "Controllu de aplicatziones cun versiones cumpatìbiles",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Segura·ti chi su config.php tuo non tèngiat <samp>appstoreenabled</samp> impostada a false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "No at fatu a si connètere a sa butega de aplicatziones o a sa butega de aplicatziones no at torradu perunu agiornamentu. Chirca a manu is agiornamentos o segura·ti chi su serbidore potzat intrare a Internet e si potzat collegare a sa butega de aplicatziones.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available" : "<strong>Totu</strong> is aplicatziones tenent una versione cumpatìbile a disponimentu pro custa versione de Nextcloud",
    "View changelog" : "Visualiza le novidade",
    "Enterprise" : "Impresa",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Pro un'impreu aziendale. Frunit semper s'ùrtimu livellu de patch, ma non s'at a agiornare deretu a s'ùrtima versione printzipale. Tale agiornamentu at a èssere a disponimentu in su momentu chi Nextcloud GmbH at a àere megioradu sa seguresa, at a àere fatu proas a iscala manna e installatziones in ambientes de importu mannu. Custu canale est a disponimentu isceti pro is clientes e frunit is pachetes Nextcloud Enterprise.",
    "Stable" : "Istàbile",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Sa versione istàbile prus reghente. Est dèghida pro s'impreu fitianu e at a èssere semper agiornada a s'ùrtima versione printzipale.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Una versione pre-publicatzione isceti pro proare is funtzionalidades noas, non pro ambientes de produtzione.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available_::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available_" : ["<strong>%n</strong>aplicatziones no tenent una versione noa cumpatìbile a disponimentu pro custa versione de Nextcloud ","<strong>%n</strong> "],
    "Apps missing updates" : "Aplicatzione no agiornadas",
    "Apps with available updates" : "Aplicatziones cun agiornamentos a disponimentu",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Càstia chi, a pustis de una versione noa, bi diat pòdere chèrrere tempus in antis chi si bidat inoghe. Publicamus in su tempus versiones noas a is utentes nostros e, a bortas, brincamus una versione, si b'at problemas. ",
    "Only notification for app updates are available." : "Sunt a disponimentu isceti is notìficas pro is agiornamentos de is aplicatziones.",
    "Checking apps for compatible updates" : "Controlla is aplicatziones pro agiornamentos cumpatìbiles",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "No at fatu a si connètere a sa butega de aplicatziones o a sa butega de aplicatziones no at torradu perunu agiornamentu. Chirca a manu is agiornamentos o segura·ti chi su serbidore potzat intrare a Internet e si potzat collegare a sa butega de aplicatziones.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Totu</strong> is aplicatziones tenent un'agiornamentu a disponimentu pro custa versione",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong>  aplicatziones non tenent un'agiornamentu a disponimentu pro custa versione","<strong>%n</strong>"]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.8.tgz: nextcloud/apps/updatenotification/l10n/sc.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} est a disponimentu. Otene è àteras informatziones subra comente pònnere in esecutzione s'agiornamentu.",
    "Channel updated" : "Canale agiornadu",
    "Web updater is disabled" : "S'agiornamentu web est disativadu",
    "Update notifications" : "Notìficas de is agiornamentos",
    "The update server could not be reached since %d days to check for new updates." : "Su serbidore no si podet sighire dae %d dies pro controllare si b'at agiornamentos noos.",
    "Please check the Nextcloud and server log files for errors." : "Controla is archìvios de registru de Nextcloud e de su serbidore a sa chirca de is errores.",
    "Update to %1$s is available." : "Agiornamentu a %1$s a disponimentu.",
    "Update for %1$s to version %2$s is available." : "Est a disponimentu s'agiornamentu de %1$s a sa versione %2$s.",
    "Update for {app} to version %s is available." : "Est a disponimentu s'agiornamentu de {app} a sa versione %s.",
    "Update notification" : "Notìficas de agiornamentu",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Visualiza is notìficas de is agiornamentos pro Nextcloud e fruni su SSO pro sa funtzione de agiornamentu.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Sa versione chi ses ponende in esecutzione non s'est mantenende prus. Segura·ti de agiornare a una versione suportada cantu in antis.",
    "Apps missing compatible version" : "Aplicatziones sena versione cumpatìbile",
    "View in store" : "Visualiza in sa butega",
    "Apps with compatible version" : "Aplicatzione cun versione cumpatìbile",
    "Open updater" : "Aberi sa funtzione de agiornamentu",
    "Download now" : "Iscàrriga immoe",
    "Please use the command line updater to update." : "Imprea sa funtzione de agiornamentu dae sa lìnia de cumandu pro agiornare.",
    "What's new?" : "Ite noas?",
    "The update check is not yet finished. Please refresh the page." : "Su controllu de is agiornamentos no est terminadu ancora. Agiorna sa pàgina.",
    "Your version is up to date." : "Sa versione tua est agiornada.",
    "A non-default update server is in use to be checked for updates:" : "Ses impreende unu serbidore non predefinidu pro controllare is agiornamentos:",
    "Update channel:" : "Canale de agiornamentu:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Podes agiornare semper a una versine noa. Ma non podes torrare mai a una versione de in antis.",
    "Notify members of the following groups about available updates:" : "Notìficas a is membros de is grupos in fatu in contu de sa disponibilidade de agiornamentos:",
    "Only notifications for app updates are available." : "Sunt a disponimentu isceti is notìficas pro is agiornamentos de is aplicatziones.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Su canale de agiornamentu seletzionadu faghet chi is notìficas dedicadas a su serbidores siant in disusu.",
    "The selected update channel does not support updates of the server." : "Su canale de agiornamentu seletzionadu non suportat is agiornamentos de su serbidore.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Una versione noa est a disponimentu: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Càstia chi, a pustis de una versione noa, s'agiornamentu si visualizat isceti a pustis de sa prima versione minore o a pustis. Publicamus in su tempus versiones noas a is utentes nostros e, a bortas, brincamus una versione, si essint a campu problemas. Àteras informatziones in contu de agiornamentos e de is canales de publicatzione {link} ",
    "Checked on {lastCheckedDate}" : "Controlladu su {lastCheckedDate}",
    "Checking apps for compatible versions" : "Controllu de aplicatziones cun versiones cumpatìbiles",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Segura·ti chi su config.php tuo non tèngiat <samp>appstoreenabled</samp> impostada a false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "No at fatu a si connètere a sa butega de aplicatziones o a sa butega de aplicatziones no at torradu perunu agiornamentu. Chirca a manu is agiornamentos o segura·ti chi su serbidore potzat intrare a Internet e si potzat collegare a sa butega de aplicatziones.",
    "View changelog" : "Visualiza le novidade",
    "Enterprise" : "Impresa",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Pro un'impreu aziendale. Frunit semper s'ùrtimu livellu de patch, ma non s'at a agiornare deretu a s'ùrtima versione printzipale. Tale agiornamentu at a èssere a disponimentu in su momentu chi Nextcloud GmbH at a àere megioradu sa seguresa, at a àere fatu proas a iscala manna e installatziones in ambientes de importu mannu. Custu canale est a disponimentu isceti pro is clientes e frunit is pachetes Nextcloud Enterprise.",
    "Stable" : "Istàbile",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Sa versione istàbile prus reghente. Est dèghida pro s'impreu fitianu e at a èssere semper agiornada a s'ùrtima versione printzipale.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Una versione pre-publicatzione isceti pro proare is funtzionalidades noas, non pro ambientes de produtzione.",
    "Apps missing updates" : "Aplicatzione no agiornadas",
    "Apps with available updates" : "Aplicatziones cun agiornamentos a disponimentu",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Càstia chi, a pustis de una versione noa, bi diat pòdere chèrrere tempus in antis chi si bidat inoghe. Publicamus in su tempus versiones noas a is utentes nostros e, a bortas, brincamus una versione, si b'at problemas. ",
    "Only notification for app updates are available." : "Sunt a disponimentu isceti is notìficas pro is agiornamentos de is aplicatziones.",
    "Checking apps for compatible updates" : "Controlla is aplicatziones pro agiornamentos cumpatìbiles",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "No at fatu a si connètere a sa butega de aplicatziones o a sa butega de aplicatziones no at torradu perunu agiornamentu. Chirca a manu is agiornamentos o segura·ti chi su serbidore potzat intrare a Internet e si potzat collegare a sa butega de aplicatziones.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Totu</strong> is aplicatziones tenent un'agiornamentu a disponimentu pro custa versione",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong>  aplicatziones non tenent un'agiornamentu a disponimentu pro custa versione","<strong>%n</strong>"],
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available" : "<strong>Totu</strong> is aplicatziones tenent una versione cumpatìbile a disponimentu pro custa versione de Nextcloud",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available_::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available_" : ["<strong>%n</strong>aplicatziones no tenent una versione noa cumpatìbile a disponimentu pro custa versione de Nextcloud ","<strong>%n</strong> "]
},
"nplurals=2; plural=(n != 1);");
